@@ -1,13 +1,12 @@
 package IPC::PubSub::Cache::JiftyDBI::Stash::Item;
-
-use warnings;
 use strict;
+use warnings;
 
 use vars qw/$TABLE_PREFIX/;
 
 use Jifty::DBI::Schema;
 use Jifty::DBI::Record schema {
-    column key    => type is 'text';
+    column data_key    => type is 'text';
     column val    => type is 'blob', filters are 'Jifty::DBI::Filter::Storable';
     column expiry => type is 'int';
 };
